/* Uni-Form by Dragan Babic [Superawesome Industries]  - http: //sprawsm.com/uni-form/ */ 
/* Some rights reserved - http: //creativecommons.org/licenses/by-sa/2.5/ */
/* Do not edit this file directly, make your changes to uni-form.css in the same folder */

/* ------------------------------------------------------------------------------ */

.uniForm{ margin: 0; padding: 0; position: relative; z-index: 1; } /* reset stuff */

  /* Some generals and more resets */
  .uniForm fieldset{ border: none; margin: 0; padding: 0; position: relative; }
    .uniForm fieldset legend{ margin: 0; padding: 0; }

    /* This is the main unit that contains our form elements */
    .uniForm .ctrlHolder,
    .uniForm .buttonHolder{ margin: 0; padding: 0; clear: both; }

    /* Clear all floats */ 
    .uniForm:after,
      .uniForm .buttonHolder:after, 
      .uniForm .ctrlHolder:after, 
        .uniForm .ctrlHolder .multiField:after,
          .uniForm .inlineLabel:after{ content: "."; display: block; height: 0; line-height: 0; font-size: 0; clear: both; min-height: 0; visibility: hidden; }

    /* A class to be used on a label that contains a checkbox or a radio button */
    .uniForm .inlineLabel,
    .uniForm .inlineLabels .inlineLabel,
    .uniForm .blockLabels .inlineLabel{ width: auto; float: none; margin: 0; display: block; }
      /* IE shows borders & padding on checkboxes and radio buttons if they are declared on an input element, remove them */
      /* Legacy/Inheritance fix */
      .uniForm .inlineLabel input,
      .uniForm .inlineLabels .inlineLabel input,
      .uniForm .blockLabels .inlineLabel input{ border: none; padding: 0; margin: 0; }

/* ------------------------------------------------------------------------------ */

    /* Styles for form controls where labels are above the input elements */
    /* Set the class of the parent (preferably to a fieldset) to .blockLabels */

      .uniForm label,
      .uniForm .label,
      .uniForm .blockLabels label,
      .uniForm .blockLabels .label{ display: block; float: none; padding: 0; line-height: 100%; width: auto; }

      /* Float the input elements */
      .uniForm .textInput,
      .uniForm .blockLabels .textInput,
      .uniForm .blockLabels .fileUpload,
      .uniForm .selectInput,
      .uniForm .blockLabels .selectInput,
      .uniForm .blockLabels select,
      .uniForm textarea,
      .uniForm .blockLabels textarea{ float: left; }
      
      /* Postition the hints */
      .uniForm .formHint,
      .uniForm .blockLabels .formHint{ float: right; margin: 0; clear: none; }
      
      /* Position the elements inside combo boxes (multiple selects/checkboxes/radio buttons per unit) */
      .uniForm .multiField,
      .uniForm .blockLabels .multiField{ width: auto; float: left; }
        .uniForm .multiField .inlineLabel,
        .uniForm .blockLabels .multiField .inlineLabel{ display: block; margin: 0 0 .5em 0; }
        .uniForm .multiField .blockLabel,
        .uniForm .blockLabels .multiField .blockLabel{ float: left; width: auto; margin: 0; }
        .uniForm .multiField .blockLabel .textInput,
        .uniForm .multiField .blockLabel .selectInput,
        .uniForm .multiField .blockLabel select,
        .uniForm .blockLabels .multiField .blockLabel .textInput,
        .uniForm .blockLabels .multiField .blockLabel .selectInput,
        .uniForm .blockLabels .multiField .blockLabel select{ width: 100%; margin: 0; }

/* ------------------------------------------------------------------------------ */

    /* Styles for form controls where labels are in line with the input elements */
    /* Set the class of the parent (preferably to a fieldset) to .inlineLabels */
        .uniForm .inlineLabels label,
        .uniForm .inlineLabels .label{ float: left; margin: 0; padding: 0; line-height: 100%; position: relative; }
        
        /* Float the input elements */
        .uniForm .inlineLabels .textInput,
        .uniForm .inlineLabels .fileUpload,        
        .uniForm .inlineLabels .selectInput,
        .uniForm .inlineLabels select,
        .uniForm .inlineLabels textarea{ float: left; }

      /* Postition the hints */
      .uniForm .inlineLabels .formHint{ clear: both; float: none; }
      .uniForm .inlineLabels .multiField{ float: left; }
      .uniForm .inlineLabels .multiField .inlineLabel{}
      .uniForm .inlineLabels .multiField .blockLabel{}
        .uniForm .inlineLabels .multiField .blockLabel .textInput,
        .uniForm .inlineLabels .multiField .blockLabel .selectInput,
        .uniForm .inlineLabels .multiField .blockLabel select{ display: block; width: 100%; float: none; }
        .uniForm .inlineLabels .multiField select{ float: left; }
      
/* ------------------------------------------------------------------------------ */

    /* Required fields asterisk styling for .blockLabels */
    .uniForm label em,
    .uniForm .label em,
    .uniForm .blockLabels label em,
    .uniForm .blockLabels .label em{ position: absolute; left: -7px; }
    
    /* Required fields asterisk styling for .inlineLabels */
    .uniForm .inlineLabels label em,
    .uniForm .inlineLabels .label em{ display: block; position: absolute; left: auto; right: 0; font-style: normal; font-weight: bold; }
    .uniForm .inlineLabel em{ position: absolute; left: 7px; }

/* ------------------------------------------------------------------------------ */

    /* Messages */
    .uniForm #errorMsg,
    .uniForm .error{
    }
      .uniForm #errorMsg dt,
      .uniForm #errorMsg h3{
      }
      .uniForm #errorMsg dd{
      }
        .uniForm #errorMsg ol{
        }
          .uniForm #errorMsg ol li{
          }
      .uniForm .errorField{
      }
    
    .uniForm #OKMsg{
    }

/* ------------------------------------------------------------------------------ */

    /* Columns */
    
    .uniForm .col{ float: left; }
    .uniForm .col.first{}
    .uniForm .col.last{}