#wmd-button-bar {
    width: 300px;
}

#wmd-preview-area { 
    width: 620px;
}

.wmd-button-row {
    position: relative; 
    margin: 10px 0 5px 0;
    padding: 0; 
    height: 20px;
}

.wmd-spacer {
    width: 0; 
    height: 22px; 
    margin-left: 3px;
    margin-right:3px;
    position: relative;
    display: inline-block;  zoom:1; *display:inline;
    list-style: none;
}

.wmd-button {
    width: 20px; 
    height: 20px; 
    position: relative;
    background-image: url(../img/wmd-buttons.png);
    background-repeat: no-repeat;
    background-position: 0px 0px;
    display: inline-block; zoom:1; *display:inline;
    list-style: none;
    border: 1px solid #ddd;
}

.wmd-button a {
    width: 20px; 
    height: 20px; 
    position: absolute;
    display: inline-block; 
}


/* sprite button slicing style information */
.wmd-bold-button            {background-position: 0px   0px;}
.wmd-bold-button:hover      {background-position: 0px -40px;}
.wmd-bold-button.disabled   {background-position: 0px -20px;}

.wmd-italic-button            {background-position: -20px   0px;}
.wmd-italic-button:hover      {background-position: -20px -40px;}
.wmd-italic-button.disabled   {background-position: -20px -20px;}

.wmd-link-button            {background-position: -40px   0px;}
.wmd-link-button:hover      {background-position: -40px -40px;}
.wmd-link-button.disabled   {background-position: -40px -20px;}

.wmd-quote-button            {background-position: -60px   0px;}
.wmd-quote-button:hover      {background-position: -60px -40px;}
.wmd-quote-button.disabled   {background-position: -60px -20px;}

.wmd-code-button            {background-position: -80px   0px;}
.wmd-code-button:hover      {background-position: -80px -40px;}
.wmd-code-button.disabled   {background-position: -80px -20px;}

.wmd-image-button            {background-position: -100px   0px;}
.wmd-image-button:hover      {background-position: -100px -40px;}
.wmd-image-button.disabled   {background-position: -100px -20px;}

.wmd-olist-button            {background-position: -120px   0px;}
.wmd-olist-button:hover      {background-position: -120px -40px;}
.wmd-olist-button.disabled   {background-position: -120px -20px;}

.wmd-ulist-button            {background-position: -140px   0px;}
.wmd-ulist-button:hover      {background-position: -140px -40px;}
.wmd-ulist-button.disabled   {background-position: -140px -20px;}

.wmd-heading-button            {background-position: -160px   0px;}
.wmd-heading-button:hover      {background-position: -160px -40px;}
.wmd-heading-button.disabled   {background-position: -160px -20px;}

.wmd-hr-button            {background-position: -180px   0px;}
.wmd-hr-button:hover      {background-position: -180px -40px;}
.wmd-hr-button.disabled   {background-position: -180px -20px;}

.wmd-undo-button            {background-position: -200px   0px;}
.wmd-undo-button:hover      {background-position: -200px -40px;}
.wmd-undo-button.disabled   {background-position: -200px -20px;}

.wmd-redo-button            {background-position: -220px   0px;}
.wmd-redo-button:hover      {background-position: -220px -40px;}
.wmd-redo-button.disabled   {background-position: -220px -20px;}

.wmd-help-button            {background-position: -240px   0px;}
.wmd-help-button:hover      {background-position: -240px -40px;}
.wmd-help-button.disabled   {background-position: -240px -20px;}

.wmd-help-button    {position:absolute;top:0px;right: 0px; background-position: -240px 0;}


.wmd-prompt-dialog {
    border: 1px solid #ddd;
    background-color: #efefef;
    border-radius: 5px;
    box-shadow: 2px 2px 4px rgba(0, 0, 0, 0.5);
}

